@@ -386,14 +386,15 @@ $$ language plpgsql;
 create function jaaql__delete_application(the_application text) returns void as
 $$
 DECLARE
-    username text;
+    fetched_username text;
 BEGIN
-    SELECT split_part(public_credentials, ':', 1) as username into username FROM jaaql__user WHERE application = the_application;
-    EXECUTE 'DROP ROLE ' || quote_ident(username);
-    DELETE FROM jaaql__authorization_configuration WHERE role = username;
-    UPDATE jaaql__user SET deleted = current_timestamp WHERE application = the_application;
-    UPDATE jaaql__credentials_node SET deleted = current_timestamp WHERE role = username;
+    SELECT split_part(public_credentials, ':', 1) as username into fetched_username FROM jaaql__user WHERE application = the_application;
+    EXECUTE 'DROP ROLE ' || quote_ident(fetched_username);
+    DELETE FROM jaaql__authorization_configuration WHERE role = fetched_username;
+    UPDATE jaaql__user SET deleted = current_timestamp, application = null, public_credentials = null, is_public = false WHERE application = the_application;
+    UPDATE jaaql__credentials_node SET deleted = current_timestamp WHERE role = fetched_username;
     DELETE FROM jaaql__application WHERE name = the_application;
+    DELETE FROM jaaql__default_role WHERE the_role = fetched_username;
 END
 $$ language plpgsql;
 
